@@ -11,6 +11,7 @@ from tiddlyweb.model.policy import ForbiddenError, UserRequiredError
 from tiddlyweb.filters import (FilterIndexRefused, parse_for_filters,
         recursive_filter)
 from tiddlyweb.store import NoBagError, StoreError
+from tiddlyweb.specialbag import get_bag_retriever, SpecialBagError
 
 
 def get_tiddlers_from_recipe(recipe, environ=None):
@@ -26,12 +27,25 @@ def get_tiddlers_from_recipe(recipe, environ=None):
     store = recipe.store
     uniquifier = {}
     for bag, filter_string in recipe.get_recipe(template):
+
         if isinstance(bag, basestring):
-            bag = Bag(name=bag)
-        bag.store = store
-        for tiddler in _filter_tiddlers_from_bag(bag, filter_string,
-                environ=environ):
-            uniquifier[tiddler.title] = tiddler
+            retriever = get_bag_retriever(environ, bag)
+            if not retriever:
+                bag = Bag(name=bag)
+                retriever = store.list_bag_tiddlers
+            else:
+                retriever = retriever[0]
+        else:
+            retriever = store.list_bag_tiddlers
+
+        try:
+            for tiddler in filter_tiddlers(retriever(bag), filter_string,
+                    environ=environ):
+                uniquifier[tiddler.title] = tiddler
+        except SpecialBagError, exc:
+            raise NoBagError('unable to retrieve from special bag: %s, %s'
+                    % (bag, exc))
+
     return uniquifier.values()
 
 
