@@ -25,6 +25,9 @@ from tiddlyweb.web.sendtiddlers import send_tiddlers
 from tiddlyweb.web.validator import validate_tiddler, InvalidTiddlerError
 
 
+CACHE_CONTROL_FIELD = '_cache-max-age'
+
+
 def get(environ, start_response):
     """
     Get a representation of a single tiddler,
@@ -445,6 +448,12 @@ def _send_tiddler(environ, start_response, tiddler):
 
     vary_header = ('Vary', 'Accept')
     cache_header = ('Cache-Control', 'no-cache')
+    if CACHE_CONTROL_FIELD in tiddler.fields:
+        try:
+            cache_header = ('Cache-Control', 'max-age=%s'
+                    % int(tiddler.fields[CACHE_CONTROL_FIELD]))
+        except ValueError:
+            pass  # if the value is not an int use default header
     content_header = ('Content-Type', str(mime_type))
     response = [cache_header, content_header, vary_header]
     if last_modified:
